==> blesta-5.10.2.zip: blesta/plugins/system_overview/language/de_de/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.graph_line_name.new'] = 'Neu';
$lang['AdminMain.graph_line_name.suspended'] = 'Aufgehängt';
$lang['AdminMain.graph_line_name.canceled'] = 'Abgesagt';
$lang['AdminMain.graph_line_name.active'] = 'Aktiv';
$lang['AdminMain.graph_name.graph_clients'] = 'Kunden';
$lang['AdminMain.graph_name.graph_services'] = 'Dienstleistungen';
$lang['AdminMain.settings.submit_settings'] = 'Einstellungen aktualisieren';
$lang['AdminMain.settings.submit_cancel'] = 'Zurück zur Übersicht';
$lang['AdminMain.settings.date_range'] = 'Diagramm Datumsbereich';
$lang['AdminMain.settings.show_legend'] = 'Legende anzeigen';
$lang['AdminMain.settings.tooltip_show_one_tab'] = 'Die Diagramme werden nicht mehr in Registerkarten getrennt, sondern alle in einer einzigen Registerkarte angezeigt.';
$lang['AdminMain.settings.show_one_tab'] = 'Nur eine Registerkarte anzeigen';
$lang['AdminMain.settings.heading_settings'] = 'Einstellungen';
$lang['AdminMain.settings.graph_services'] = 'Dienstleistungen Graph';
$lang['AdminMain.settings.text_graphs_services'] = 'Prüfen Sie, welche Diagramme auf der Registerkarte Dienste erscheinen sollen.';
$lang['AdminMain.settings.heading_services'] = 'Registerkarte Dienste';
$lang['AdminMain.settings.graph_clients'] = 'Kunden Grafik';
$lang['AdminMain.settings.text_graphs_clients'] = 'Prüfen Sie, welche Diagramme auf der Registerkarte "Kunden" erscheinen sollen.';
$lang['AdminMain.settings.heading_clients'] = 'Registerkarte Kunden';
$lang['AdminMain.settings.pending_orders'] = 'Anhängige Aufträge';
$lang['AdminMain.settings.open_tickets'] = 'Offene Tickets';
$lang['AdminMain.settings.recurring_invoices'] = 'Wiederkehrende Rechnungen';
$lang['AdminMain.settings.active_users_today'] = 'Heute aktive Benutzer';
$lang['AdminMain.settings.services_scheduled_cancellation'] = 'Zur Stornierung vorgesehene Dienste';
$lang['AdminMain.settings.services_active'] = 'Aktive Dienste';
$lang['AdminMain.settings.clients_active'] = 'Aktive Kunden';
$lang['AdminMain.settings.text_options'] = 'Überprüfen Sie die Optionen, die in der Systemübersicht angezeigt werden.';
$lang['AdminMain.settings.heading_statistics'] = 'Statistik';
$lang['AdminMain.date_range.days'] = '%1$s Tage';
$lang['AdminMain.overview.tooltip_last_activity_minutes'] = 'vor %1$s Minuten';
$lang['AdminMain.overview.tooltip_last_activity_minute'] = 'vor 1 Minute';
$lang['AdminMain.overview.tooltip_last_activity_now'] = 'Gerade jetzt';
$lang['AdminMain.overview.tooltip_location'] = 'Standort';
$lang['AdminMain.overview.tooltip_activity'] = 'Letzte Aktivität';
$lang['AdminMain.overview.tab_services'] = 'Dienstleistungen';
$lang['AdminMain.overview.tab_clients'] = 'Kunden';
$lang['AdminMain.overview.tab_all'] = 'Schaubilder';
$lang['AdminMain.overview.heading_users'] = 'Neue Benutzer';
$lang['AdminMain.overview.statistic.open_tickets'] = 'Offene Tickets';
$lang['AdminMain.overview.statistic.pending_orders'] = 'Anhängige Aufträge';
$lang['AdminMain.overview.statistic.recurring_invoices'] = 'Wiederkehrende Rechnungen';
$lang['AdminMain.overview.statistic.active_users_today'] = 'Heute aktive Benutzer';
$lang['AdminMain.overview.statistic.services_scheduled_cancellation'] = 'Zur Stornierung vorgesehene Dienste';
$lang['AdminMain.overview.statistic.services_active'] = 'Aktive Dienste';
$lang['AdminMain.overview.statistic.clients_active'] = 'Aktive Kunden';
$lang['AdminMain.index.boxtitle_overview'] = 'System-Übersicht';
$lang['AdminMain.!success.options_updated'] = 'Die Einstellungen der Systemübersicht wurden erfolgreich aktualisiert!';

==> blesta-5.11.4.zip: blesta/plugins/system_overview/language/de_de/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.graph_line_name.new'] = 'Neu';
$lang['AdminMain.graph_line_name.suspended'] = 'Aufgehängt';
$lang['AdminMain.graph_line_name.canceled'] = 'Abgesagt';
$lang['AdminMain.graph_line_name.active'] = 'Aktiv';
$lang['AdminMain.graph_name.graph_clients'] = 'Kunden';
$lang['AdminMain.graph_name.graph_services'] = 'Dienstleistungen';
$lang['AdminMain.settings.submit_settings'] = 'Einstellungen aktualisieren';
$lang['AdminMain.settings.submit_cancel'] = 'Zurück zur Übersicht';
$lang['AdminMain.settings.date_range'] = 'Diagramm Datumsbereich';
$lang['AdminMain.settings.show_legend'] = 'Legende anzeigen';
$lang['AdminMain.settings.tooltip_show_one_tab'] = 'Die Diagramme werden nicht mehr in Registerkarten getrennt, sondern alle in einer einzigen Registerkarte angezeigt.';
$lang['AdminMain.settings.show_one_tab'] = 'Nur eine Registerkarte anzeigen';
$lang['AdminMain.settings.heading_settings'] = 'Einstellungen';
$lang['AdminMain.settings.graph_services'] = 'Dienstleistungen Graph';
$lang['AdminMain.settings.text_graphs_services'] = 'Prüfen Sie, welche Diagramme auf der Registerkarte Dienste erscheinen sollen.';
$lang['AdminMain.settings.heading_services'] = 'Registerkarte Dienste';
$lang['AdminMain.settings.graph_clients'] = 'Kunden Grafik';
$lang['AdminMain.settings.text_graphs_clients'] = 'Prüfen Sie, welche Diagramme auf der Registerkarte "Kunden" erscheinen sollen.';
$lang['AdminMain.settings.heading_clients'] = 'Registerkarte Kunden';
$lang['AdminMain.settings.pending_orders'] = 'Anhängige Aufträge';
$lang['AdminMain.settings.open_tickets'] = 'Offene Tickets';
$lang['AdminMain.settings.recurring_invoices'] = 'Wiederkehrende Rechnungen';
$lang['AdminMain.settings.active_users_today'] = 'Heute aktive Benutzer';
$lang['AdminMain.settings.services_scheduled_cancellation'] = 'Zur Stornierung vorgesehene Dienste';
$lang['AdminMain.settings.services_active'] = 'Aktive Dienste';
$lang['AdminMain.settings.clients_active'] = 'Aktive Kunden';
$lang['AdminMain.settings.text_options'] = 'Überprüfen Sie die Optionen, die in der Systemübersicht angezeigt werden.';
$lang['AdminMain.settings.heading_statistics'] = 'Statistik';
$lang['AdminMain.date_range.days'] = '%1$s Tage';
$lang['AdminMain.overview.tooltip_last_activity_minutes'] = 'vor %1$s Minuten';
$lang['AdminMain.overview.tooltip_last_activity_minute'] = 'vor 1 Minute';
$lang['AdminMain.overview.tooltip_last_activity_now'] = 'Gerade jetzt';
$lang['AdminMain.overview.tooltip_location'] = 'Standort';
$lang['AdminMain.overview.tooltip_activity'] = 'Letzte Aktivität';
$lang['AdminMain.overview.tab_services'] = 'Dienstleistungen';
$lang['AdminMain.overview.tab_clients'] = 'Kunden';
$lang['AdminMain.overview.tab_all'] = 'Schaubilder';
$lang['AdminMain.overview.heading_users'] = 'Neue Benutzer';
$lang['AdminMain.overview.statistic.open_tickets'] = 'Offene Tickets';
$lang['AdminMain.overview.statistic.pending_orders'] = 'Anhängige Aufträge';
$lang['AdminMain.overview.statistic.recurring_invoices'] = 'Wiederkehrende Rechnungen';
$lang['AdminMain.overview.statistic.active_users_today'] = 'Heute aktive Benutzer';
$lang['AdminMain.overview.statistic.services_scheduled_cancellation'] = 'Zur Stornierung vorgesehene Dienste';
$lang['AdminMain.overview.statistic.services_active'] = 'Aktive Dienste';
$lang['AdminMain.overview.statistic.clients_active'] = 'Aktive Kunden';
$lang['AdminMain.index.boxtitle_overview'] = 'System-Übersicht';
$lang['AdminMain.!success.options_updated'] = 'Die Einstellungen der Systemübersicht wurden erfolgreich aktualisiert!';
$lang['AdminMain.date_range.day'] = '1 Tag';
$lang['AdminMain.date_range.month'] = 'Aktueller Monat';
$lang['AdminMain.date_range.ytd'] = 'Bisheriges Jahr';
